@@ -741,8 +741,6 @@ FXint GMPlayerManager::run(int& argc,char** argv) {
     }
 #endif
 
-  update_tray_icon();
-
   lastfm = new GMAudioScrobbler(this,ID_SCROBBLER_ERROR);
 
 #ifdef HAVE_DBUS
@@ -751,6 +749,8 @@ FXint GMPlayerManager::run(int& argc,char** argv) {
     mpris        = new GMMediaPlayerService(sessionbus);
     gsd          = new GMSettingsDaemon(sessionbus,this,ID_GNOME_SETTINGS_DAEMON);
     gsd->GrabMediaPlayerKeys("gogglesmm");
+
+    notifydaemon->init();
     }
 #endif
 
@@ -758,6 +758,10 @@ FXint GMPlayerManager::run(int& argc,char** argv) {
   if (!url.empty())
     open(url);
 
+#ifndef HAVE_DBUS
+  update_tray_icon();
+#endif
+
   /// Run the application
   return application->run();
   }
@@ -825,18 +829,20 @@ void GMPlayerManager::exit() {
 
 
 void GMPlayerManager::update_tray_icon() {
-  if (trayicon && !preferences.gui_tray_icon) {
-    delete trayicon;
-    trayicon=NULL;
-    }
-  else if (!trayicon && preferences.gui_tray_icon) {
-    trayicon = new GMTrayIcon(application);
-    trayicon->create();
-    if (!trayicon->dock()) {
-      preferences.gui_tray_icon=false;
+  if (!preferences.gui_tray_icon_disabled) {
+    if (trayicon && !preferences.gui_tray_icon) {
       delete trayicon;
       trayicon=NULL;
       }
+    else if (!trayicon && preferences.gui_tray_icon) {
+      trayicon = new GMTrayIcon(application);
+      trayicon->create();
+      if (!trayicon->dock()) {
+        preferences.gui_tray_icon=false;
+        delete trayicon;
+        trayicon=NULL;
+        }
+      }
     }
   }
 
@@ -1066,6 +1072,7 @@ void GMPlayerManager::open(const FXString & uri) {
       }
     else {
       /// Reset Active Track
+      trackinfoset = trackinfo.loadTag(filename);
       getTrackView()->mark(-1);
       }
     }
@@ -1076,9 +1083,6 @@ void GMPlayerManager::open(const FXString & uri) {
 
   /// Play File
   if (play(filename) && local) {
-    if (source==NULL) {
-      player->getTrackInformation(trackinfo);
-      }
     update_track_display();
     }
 
@@ -1715,7 +1719,7 @@ void GMPlayerManager::display_track_notification() {
       /// but try finding a notification daemon that actually implements it...
       /// http://www.galago-project.org/specs/notification/0.9/index.html
       body.substitute("&","&amp;");
-      notifydaemon->notify("gogglesmm","gmm",trackinfo.title.text(),body.text(),-1,mainwindow->getSmallCover());
+      notifydaemon->notify(trackinfo.title.text(),body.text(),-1,mainwindow->getSmallCover());
       }
     if (mpris) mpris->notify_track_change(trackinfo);
     }
