@@ -199,6 +199,13 @@ FXString gm_url_encode(const FXString& url){
   }
 
 
+FXString gm_make_url(const FXString & in) {
+  if (in[0]=='/')
+    return GMURL::fileToURL(in);
+  else
+    return in;
+  }
+
 FXdouble gm_parse_number(const FXString & str) {
   if (str.empty())
     return NAN;
@@ -624,3 +631,15 @@ void gm_colorize_bitmap(FXImage * icon,FXColor nc) {
     }
   }
 
+void gm_bgra_to_rgba(FXColor * inbuf,FXColor * outbuf, FXint len) {
+   FXuchar * in  = reinterpret_cast<FXuchar*>(inbuf);
+   FXuchar * out = reinterpret_cast<FXuchar*>(outbuf);
+   for (FXint i=0;i<(len*4);i+=4) {
+      out[i+0]=in[i+2]; // r
+      out[i+1]=in[i+1]; // g
+      out[i+2]=in[i+0]; // b
+      out[i+3]=in[i+3]; // a
+      }
+  }
+
+
